==> adx-center-api-0.0.10-sources.jar: cn/com/duiba/tuia/adx/center/api/remoteservice/adx/RemoteAdvertisingSpaceTypeService.java <==
package cn.com.duiba.tuia.adx.center.api.remoteservice.adx;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.adx.center.api.dto.adx.*;

import java.util.List;

/**
 * @author shenjiaqing
 * @description 广告位类型功能开发
 * @data 2019/11/18
 */
@AdvancedFeignClient
public interface RemoteAdvertisingSpaceTypeService {

    /**
     * 功能描述 根据Adx平台类型获取广告位类型列表
     *
     * @param [adxType]
     * @return java.util.List<cn.com.duiba.tuia.activity.center.api.dto.adx.AdvertisingSpaceTypesDto>
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    List<AdvertisingSpaceTypesDto> getAllByAdxType(Integer adxType);

    /**
     * 功能描述 检查广告位类型名称的唯一性
     *
     * @param [typeName]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:38 2019/11/19
     **/
    boolean typeNameIsExists(String typeName, Long id, Integer adxType);

    /**
     * 功能描述 检查Adx对应广告位类型Id的唯一性
     *
     * @param [templateId]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 17:33 2019/11/20
     **/
    boolean templateIdIsExists(String templateId, Long id, Integer adxType);

    /**
     * 功能描述 添加广告位类型
     *
     * @param [dto]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    boolean insert(AdvertisingSpaceTypeInsertDto dto);

    /**
     * 功能描述 编辑广告位类型
     *
     * @param [dto]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    boolean update(AdvertisingSpaceTypeUpdateDto dto);

    /**
     * 功能描述 根据广告位类型ID获取广告位详情
     *
     * @param [id]
     * @return cn.com.duiba.tuia.activity.center.api.dto.adx.AdvertisingSpaceTypeDto
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    AdvertisingSpaceTypeDto getAdSpaceTypeById(Long id);

    /**
     * 功能描述 删除广告位类型
     *
     * @param [id]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:44 2019/11/19
     **/
    boolean delete(Long id, boolean isDeleteStyle);

    /**
     * 功能描述 根据广告位类型ID获取广告位ID
     *
     * @param [id]
     * @return java.lang.String
     * @author shenjiaqing
     * @date 14:36 2019/11/19
     **/
    String getAdPositionIdByAdTypeId(Long id);

    /**
     * 功能描述 根据adxType查询广告位类型
     *
     * @param [adxType]
     * @return java.util.List<cn.com.duiba.tuia.activity.center.api.dto.adx.AdvertisingSpaceTypesDto>
     * @author shenjiaqing
     * @date 9:46 2019/11/21
     **/
    List<AdvertisingSpaceTypesDto> getTypeNameByAdxType(Integer adxType);

    /**
     * 功能描述 根据adxTypeList查询广告位类型列表
     *
     * @param adxTypeList
     * @return java.util.List<cn.com.duiba.tuia.activity.center.api.dto.adx.AdvertisingSpaceTypesDto>
     * @author shenjiaqing
     * @date 9:46 2019/11/21
     **/
    List<AdvertisingSpaceTypesDto> getTypeNameByAdxTypeList(List<Integer> adxTypeList);

    /**
     * 功能描述 查看此广告位是否存在
     *
     * @param [id]
     * @return boolean
     * @author shenjiaqing
     * @date 10:29 2019/11/25
     **/
    boolean adTypeIsExists(Long id);

    /**
     * 功能描述 查询指定推广组下的所有广告位类型的ADX广告位ID
     * @author shenjiaqing
     * @date 12:23 2019/12/5
     * @param [adxType, id]
     * @return cn.com.duiba.tuia.activity.center.api.dto.adx.AdvertisingSpaceTypesDto
     **/
    List<AdvertisingSpaceTypesDto> getAllAdPositionIdByAdxType(Integer adxType, Long id);

    /**
     * 流量智能筛选
     */
    SlotFlowFilterDTO getLatestFlowFilterAdBlock(Integer adxType, String externalAdBlockTypeId, String externalAppId, String externalAdBlockId);
}

==> adx-center-api-0.0.15-sources.jar: cn/com/duiba/tuia/adx/center/api/remoteservice/adx/RemoteAdvertisingSpaceTypeService.java <==
package cn.com.duiba.tuia.adx.center.api.remoteservice.adx;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.adx.center.api.dto.adx.*;

import java.util.List;

/**
 * @author shenjiaqing
 * @description 广告位类型功能开发
 * @data 2019/11/18
 */
@AdvancedFeignClient
public interface RemoteAdvertisingSpaceTypeService {

    /**
     * 功能描述 根据Adx平台类型获取广告位类型列表
     *
     * @param [adxType]
     * @return java.util.List<cn.com.duiba.tuia.adx.center.api.dto.adx.AdvertisingSpaceTypesDto>
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    List<AdvertisingSpaceTypesDto> getAllByAdxType(Integer adxType);

    /**
     * 功能描述 检查广告位类型名称的唯一性
     *
     * @param [typeName]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:38 2019/11/19
     **/
    boolean typeNameIsExists(String typeName, Long id, Integer adxType);

    /**
     * 功能描述 检查Adx对应广告位类型Id的唯一性
     *
     * @param [templateId]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 17:33 2019/11/20
     **/
    boolean templateIdIsExists(String templateId, Long id, Integer adxType);

    /**
     * 功能描述 添加广告位类型
     *
     * @param [dto]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    boolean insert(AdvertisingSpaceTypeInsertDto dto);

    /**
     * 功能描述 编辑广告位类型
     *
     * @param [dto]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    boolean update(AdvertisingSpaceTypeUpdateDto dto);

    /**
     * 功能描述 根据广告位类型ID获取广告位详情
     *
     * @param [id]
     * @return cn.com.duiba.tuia.adx.center.api.dto.adx.AdvertisingSpaceTypeDto
     * @author shenjiaqing
     * @date 13:39 2019/11/19
     **/
    AdvertisingSpaceTypeDto getAdSpaceTypeById(Long id);

    /**
     * 功能描述 删除广告位类型
     *
     * @param [id]
     * @return java.lang.Integer
     * @author shenjiaqing
     * @date 13:44 2019/11/19
     **/
    boolean delete(Long id, boolean isDeleteStyle);

    /**
     * 功能描述 根据广告位类型ID获取广告位ID
     *
     * @param [id]
     * @return java.lang.String
     * @author shenjiaqing
     * @date 14:36 2019/11/19
     **/
    String getAdPositionIdByAdTypeId(Long id);

    /**
     * 功能描述 根据adxType查询广告位类型
     *
     * @param [adxType]
     * @return java.util.List<cn.com.duiba.tuia.adx.center.api.dto.adx.AdvertisingSpaceTypesDto>
     * @author shenjiaqing
     * @date 9:46 2019/11/21
     **/
    List<AdvertisingSpaceTypesDto> getTypeNameByAdxType(Integer adxType);

    /**
     * 功能描述 根据adxTypeList查询广告位类型列表
     *
     * @param adxTypeList
     * @return java.util.List<cn.com.duiba.tuia.adx.center.api.dto.adx.AdvertisingSpaceTypesDto>
     * @author shenjiaqing
     * @date 9:46 2019/11/21
     **/
    List<AdvertisingSpaceTypesDto> getTypeNameByAdxTypeList(List<Integer> adxTypeList);

    /**
     * 功能描述 查看此广告位是否存在
     *
     * @param [id]
     * @return boolean
     * @author shenjiaqing
     * @date 10:29 2019/11/25
     **/
    boolean adTypeIsExists(Long id);

    /**
     * 功能描述 查询指定推广组下的所有广告位类型的ADX广告位ID
     * @author shenjiaqing
     * @date 12:23 2019/12/5
     * @param [adxType, id]
     * @return cn.com.duiba.tuia.adx.center.api.dto.adx.AdvertisingSpaceTypesDto
     **/
    List<AdvertisingSpaceTypesDto> getAllAdPositionIdByAdxType(Integer adxType, Long id);

    /**
     * 流量智能筛选
     */
    SlotFlowFilterDTO getLatestFlowFilterAdBlock(Integer adxType, String externalAdBlockTypeId, String externalAppId, String externalAdBlockId);
}
